import { DocNodeKind, DocNode } from './DocNode';
import { DocSection, IDocSectionParameters } from './DocSection';
import { DocBlockTag } from './DocBlockTag';
/**
 * Constructor parameters for {@link DocBlock}.
 */
export interface IDocBlockParameters extends IDocSectionParameters {
    blockTag: DocBlockTag;
}
/**
 * Represents a section that is introduced by a TSDoc block tag.
 * For example, an `@example` block.
 */
export declare class DocBlock extends DocSection {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _blockTag;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocBlockParameters);
    /**
     * The TSDoc tag that introduces this section.
     */
    readonly blockTag: DocBlockTag;
    /** @override */
    updateParameters(parameters: IDocBlockParameters): void;
    /**
     * {@inheritDoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
