import { DocNodeKind } from './DocNode';
import { DocNodeLeaf, IDocNodeLeafParameters } from './DocNodeLeaf';
/**
 * Constructor parameters for {@link DocBlockTag}.
 */
export interface IDocBlockTagParameters extends IDocNodeLeafParameters {
    tagName: string;
}
/**
 * Represents a TSDoc block tag such as `@param` or `@public`.
 */
export declare class DocBlockTag extends DocNodeLeaf {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _tagName;
    private _tagNameWithUpperCase;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocBlockTagParameters);
    /**
     * The TSDoc tag name.  TSDoc tag names start with an at-sign ("@") followed
     * by ASCII letters using "camelCase" capitalization.
     */
    readonly tagName: string;
    /**
     * The TSDoc tag name in all capitals, which is used for performing
     * case-insensitive comparisons or lookups.
     */
    readonly tagNameWithUpperCase: string;
    /** @override */
    updateParameters(parameters: IDocBlockTagParameters): void;
}
