import { DocNodeKind, IDocNodeParameters, DocNode } from './DocNode';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocCodeSpan}.
 */
export interface IDocCodeSpanParameters extends IDocNodeParameters {
    openingDelimiterExcerpt?: Excerpt;
    codeExcerpt?: Excerpt;
    code: string;
    closingDelimiterExcerpt?: Excerpt;
}
/**
 * Represents CommonMark-style code span, i.e. code surrounded by
 * backtick characters.
 */
export declare class DocCodeSpan extends DocNode {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _openingDelimiterParticle;
    private _codeParticle;
    private _closingDelimiterParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocCodeSpanParameters);
    /**
     * The text that should be rendered as code, excluding the backtick delimiters.
     */
    readonly code: string;
    /** @override */
    updateParameters(parameters: IDocCodeSpanParameters): void;
    /**
     * {@inheritDoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
