"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var DocNode_1 = require("./DocNode");
var DocParticle_1 = require("./DocParticle");
/**
 * Represents a declaration reference.
 *
 * @remarks
 * Declaration references are TSDoc expressions used by tags such as `{@link}`
 * or `{@inheritDoc}` that need to refer to another declaration.
 */
var DocDeclarationReference = /** @class */ (function (_super) {
    __extends(DocDeclarationReference, _super);
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    function DocDeclarationReference(parameters) {
        var _this = _super.call(this, parameters) || this;
        /** {@inheritDoc} */
        _this.kind = "DeclarationReference" /* DeclarationReference */;
        return _this;
    }
    Object.defineProperty(DocDeclarationReference.prototype, "packageName", {
        /**
         * The optional package name, which may optionally include an NPM scope.
         *
         * Example: `"@scope/my-package"`
         */
        get: function () {
            if (this._packageNameParticle) {
                return this._packageNameParticle.content;
            }
            else {
                return undefined;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocDeclarationReference.prototype, "importPath", {
        /**
         * The optional import path.  If a package name is provided, then if an import path is provided,
         * the path must start with a "/" delimiter; otherwise paths are resolved relative to the source file
         * containing the reference.
         *
         * Example: `"/path1/path2"`
         * Example: `"./path1/path2"`
         * Example: `"../path2/path2"`
         */
        get: function () {
            if (this._importPathParticle) {
                return this._importPathParticle.content;
            }
            else {
                return undefined;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocDeclarationReference.prototype, "memberReferences", {
        /**
         * The chain of member references that indicate the declaration being referenced.
         * If this list is empty, then either the packageName or importPath must be provided,
         * because the reference refers to a module.
         */
        get: function () {
            return this._memberReferences;
        },
        enumerable: true,
        configurable: true
    });
    /** @override */
    DocDeclarationReference.prototype.updateParameters = function (parameters) {
        _super.prototype.updateParameters.call(this, parameters);
        this._packageNameParticle = undefined;
        this._importPathParticle = undefined;
        this._importHashParticle = undefined;
        if (parameters.packageName) {
            this._packageNameParticle = new DocParticle_1.DocParticle({
                particleId: 'packageName',
                content: parameters.packageName,
                excerpt: parameters.packageNameExcerpt
            });
        }
        if (parameters.importPath) {
            this._importPathParticle = new DocParticle_1.DocParticle({
                particleId: 'importPath',
                content: parameters.importPath || '',
                excerpt: parameters.importPathExcerpt
            });
        }
        if ((parameters.packageName && this._importPathParticle) || parameters.importHashExcerpt) {
            this._importHashParticle = new DocParticle_1.DocParticle({
                particleId: 'importHash',
                content: '#',
                excerpt: parameters.importHashExcerpt
            });
        }
        this._memberReferences = parameters.memberReferences || [];
    };
    /**
     * {@inheritDoc}
     * @override
     */
    DocDeclarationReference.prototype.getChildNodes = function () {
        return DocNode_1.DocNode.trimUndefinedNodes([
            this._packageNameParticle,
            this._importPathParticle,
            this._importHashParticle
        ].concat(this._memberReferences));
    };
    return DocDeclarationReference;
}(DocNode_1.DocNode));
exports.DocDeclarationReference = DocDeclarationReference;
//# sourceMappingURL=DocDeclarationReference.js.map