"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var DocNode_1 = require("./DocNode");
var StringChecks_1 = require("../parser/StringChecks");
var DocParticle_1 = require("./DocParticle");
/**
 * Represents a TSDoc inline tag such as `{@inheritDoc}` or `{@link}`.
 */
var DocInlineTag = /** @class */ (function (_super) {
    __extends(DocInlineTag, _super);
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    function DocInlineTag(parameters) {
        var _this = _super.call(this, parameters) || this;
        /** {@inheritDoc} */
        _this.kind = "InlineTag" /* InlineTag */;
        return _this;
    }
    Object.defineProperty(DocInlineTag.prototype, "tagName", {
        /**
         * The TSDoc tag name.
         * For example, if the inline tag is `{@link Guid.toString | the toString() method}`
         * then the tag name would be `@link`.
         */
        get: function () {
            return this._tagNameParticle.content;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocInlineTag.prototype, "tagContent", {
        /**
         * The tag content.
         * For example, if the inline tag is `{@link Guid.toString | the toString() method}`
         * then the tag content would be `Guid.toString | the toString() method`.
         */
        get: function () {
            return this._tagContentParticle.content;
        },
        enumerable: true,
        configurable: true
    });
    /** @override */
    DocInlineTag.prototype.updateParameters = function (parameters) {
        StringChecks_1.StringChecks.validateTSDocTagName(parameters.tagName);
        _super.prototype.updateParameters.call(this, parameters);
        this._openingDelimiterParticle = new DocParticle_1.DocParticle({
            particleId: 'openingDelimiter',
            excerpt: parameters.openingDelimiterExcerpt,
            content: '{'
        });
        this._tagNameParticle = new DocParticle_1.DocParticle({
            particleId: 'tagName',
            excerpt: parameters.tagNameExcerpt,
            content: parameters.tagName
        });
        this._tagContentParticle = new DocParticle_1.DocParticle({
            particleId: 'tagContent',
            excerpt: parameters.tagContentExcerpt,
            content: parameters.tagContent
        });
        this._closingDelimiterParticle = new DocParticle_1.DocParticle({
            particleId: 'closingDelimiter',
            excerpt: parameters.closingDelimiterExcerpt,
            content: '}'
        });
    };
    /**
     * {@inheritDoc}
     * @override @sealed
     */
    DocInlineTag.prototype.getChildNodes = function () {
        return [
            this._openingDelimiterParticle,
            this._tagNameParticle
        ].concat(this.getChildNodesForContent(), [
            this._closingDelimiterParticle
        ]);
    };
    /**
     * Allows child classes to replace the tagContentParticle with a more detailed
     * set of nodes.
     * @virtual
     */
    DocInlineTag.prototype.getChildNodesForContent = function () {
        return [
            this._tagContentParticle
        ];
    };
    Object.defineProperty(DocInlineTag.prototype, "tagContentParticle", {
        get: function () {
            return this._tagContentParticle;
        },
        enumerable: true,
        configurable: true
    });
    return DocInlineTag;
}(DocNode_1.DocNode));
exports.DocInlineTag = DocInlineTag;
//# sourceMappingURL=DocInlineTag.js.map