"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var DocNode_1 = require("./DocNode");
var DocParticle_1 = require("./DocParticle");
/**
 * A {@link DocDeclarationReference | declaration reference} includes a chain of
 * member references represented using `DocMemberReference` nodes.
 *
 * @remarks
 * For example, `example-library#ui.controls.Button.(render:static)` is a
 * declaration reference that contains three member references:
 * `ui`, `.controls`, and `.Button`, and `.(render:static)`.
 */
var DocMemberReference = /** @class */ (function (_super) {
    __extends(DocMemberReference, _super);
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    function DocMemberReference(parameters) {
        var _this = _super.call(this, parameters) || this;
        /** {@inheritDoc} */
        _this.kind = "MemberReference" /* MemberReference */;
        return _this;
    }
    Object.defineProperty(DocMemberReference.prototype, "hasDot", {
        /**
         * True if this member reference is preceded by a dot (".") token.
         * It should be false only for the first member in the chain.
         */
        get: function () {
            return !!this._dotParticle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocMemberReference.prototype, "memberIdentifier", {
        /**
         * The identifier for the referenced member.
         * @remarks
         * Either `memberIdentifier` or `memberSymbol` may be specified, but not both.
         */
        get: function () {
            return this._memberIdentifier;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocMemberReference.prototype, "memberSymbol", {
        /**
         * The ECMAScript 6 symbol expression, which may be used instead of an identifier
         * to indicate the referenced member.
         * @remarks
         * Either `memberIdentifier` or `memberSymbol` may be specified, but not both.
         */
        get: function () {
            return this._memberSymbol;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocMemberReference.prototype, "selector", {
        /**
         * A TSDoc selector, which may be optionally when the identifier or symbol is insufficient
         * to unambiguously determine the referenced declaration.
         */
        get: function () {
            return this._selector;
        },
        enumerable: true,
        configurable: true
    });
    /** @override */
    DocMemberReference.prototype.updateParameters = function (parameters) {
        if (parameters.memberIdentifier && parameters.memberSymbol) {
            throw new Error('"memberIdentifier" or "memberSymbol" may be specified, but not both');
        }
        _super.prototype.updateParameters.call(this, parameters);
        this._dotParticle = undefined;
        this._leftParenthesisParticle = undefined;
        this._colonParticle = undefined;
        this._selector = undefined;
        this._rightParenthesisParticle = undefined;
        if (parameters.hasDot || parameters.dotExcerpt) {
            this._dotParticle = new DocParticle_1.DocParticle({
                particleId: 'dot',
                excerpt: parameters.dotExcerpt,
                content: '.'
            });
        }
        if (parameters.leftParenthesisExcerpt || parameters.selector) {
            this._leftParenthesisParticle = new DocParticle_1.DocParticle({
                particleId: 'leftParenthesis',
                excerpt: parameters.leftParenthesisExcerpt,
                content: '('
            });
        }
        this._memberIdentifier = parameters.memberIdentifier;
        this._memberSymbol = parameters.memberSymbol;
        if (parameters.colonExcerpt || parameters.selector) {
            this._colonParticle = new DocParticle_1.DocParticle({
                particleId: 'colon',
                excerpt: parameters.colonExcerpt,
                content: ':'
            });
        }
        this._selector = parameters.selector;
        if (this._leftParenthesisParticle) {
            this._rightParenthesisParticle = new DocParticle_1.DocParticle({
                particleId: 'rightParenthesis',
                excerpt: parameters.rightParenthesisExcerpt,
                content: ')'
            });
        }
    };
    /**
     * {@inheritDoc}
     * @override
     */
    DocMemberReference.prototype.getChildNodes = function () {
        return DocNode_1.DocNode.trimUndefinedNodes([
            this._dotParticle,
            this._leftParenthesisParticle,
            this._memberIdentifier,
            this._memberSymbol,
            this._colonParticle,
            this._selector,
            this._rightParenthesisParticle
        ]);
    };
    return DocMemberReference;
}(DocNode_1.DocNode));
exports.DocMemberReference = DocMemberReference;
//# sourceMappingURL=DocMemberReference.js.map