import { DocNodeKind, DocNode, IDocNodeParameters } from './DocNode';
import { DocDeclarationReference } from './DocDeclarationReference';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocMemberSymbol}.
 */
export interface IDocMemberSymbolParameters extends IDocNodeParameters {
    leftBracketExcerpt?: Excerpt;
    symbolReference: DocDeclarationReference | undefined;
    rightBracketExcerpt?: Excerpt;
}
/**
 * Represents a reference to an ECMAScript 6 symbol that is used
 * to identify a member declaration.
 *
 * @example
 *
 * In the declaration reference `{@link MyClass.([MySymbols.example]:instance)}`,
 * the member symbol `[MySymbols.example]` might be used to reference a property
 * of the class.
 */
export declare class DocMemberSymbol extends DocNode {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _leftBracketParticle;
    private _symbolReference;
    private _rightBracketParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocMemberSymbolParameters);
    /**
     * The declaration reference for the ECMAScript 6 symbol that will act as
     * the identifier for the member.
     */
    readonly symbolReference: DocDeclarationReference;
    /** @override */
    updateParameters(parameters: IDocMemberSymbolParameters): void;
    /**
     * {@inheritDoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
