import { DocNode, IDocNodeParameters } from './DocNode';
/**
 * Constructor parameters for {@link DocNodeContainer}.
 */
export interface IDocNodeContainerParameters extends IDocNodeParameters {
}
/**
 * DocNodeContainer is the base class for DocNode classes that act as a simple container
 * for other child nodes.  The child classes are {@link DocParagraph} and {@link DocSection}.
 */
export declare abstract class DocNodeContainer extends DocNode {
    private _nodes;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocNodeContainerParameters);
    /**
     * The child nodes.  Note that for subclasses {@link getChildNodes()} may enumerate
     * additional nodes that are not part of this collection.
     */
    readonly nodes: ReadonlyArray<DocNode>;
    /** @override */
    updateParameters(parameters: IDocNodeContainerParameters): void;
    /**
     * {@inheritDoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
    /**
     * Returns true if the specified `docNode` is allowed to be added as a child node.
     * The {@link appendNode()} and {@link appendNodes()} functions use this to validate their
     * inputs.
     *
     * @virtual
     */
    isAllowedChildNode(docNode: DocNode): boolean;
    /**
     * Append a node to the collection.
     */
    appendNode(docNode: DocNode): void;
    /**
     * Append nodes to the collection.
     */
    appendNodes(docNodes: ReadonlyArray<DocNode>): void;
    /**
     * Remove all nodes from the collection.
     */
    clearNodes(): void;
}
