"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var DocNode_1 = require("./DocNode");
/**
 * DocNodeContainer is the base class for DocNode classes that act as a simple container
 * for other child nodes.  The child classes are {@link DocParagraph} and {@link DocSection}.
 */
var DocNodeContainer = /** @class */ (function (_super) {
    __extends(DocNodeContainer, _super);
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    function DocNodeContainer(parameters) {
        return _super.call(this, parameters) || this;
    }
    Object.defineProperty(DocNodeContainer.prototype, "nodes", {
        /**
         * The child nodes.  Note that for subclasses {@link getChildNodes()} may enumerate
         * additional nodes that are not part of this collection.
         */
        get: function () {
            return this._nodes;
        },
        enumerable: true,
        configurable: true
    });
    /** @override */
    DocNodeContainer.prototype.updateParameters = function (parameters) {
        _super.prototype.updateParameters.call(this, parameters);
        if (this._nodes === undefined) {
            this._nodes = [];
        }
    };
    /**
     * {@inheritDoc}
     * @override
     */
    DocNodeContainer.prototype.getChildNodes = function () {
        return this._nodes;
    };
    /**
     * Returns true if the specified `docNode` is allowed to be added as a child node.
     * The {@link appendNode()} and {@link appendNodes()} functions use this to validate their
     * inputs.
     *
     * @virtual
     */
    DocNodeContainer.prototype.isAllowedChildNode = function (docNode) {
        return false;
    };
    /**
     * Append a node to the collection.
     */
    DocNodeContainer.prototype.appendNode = function (docNode) {
        if (!this.isAllowedChildNode(docNode)) {
            throw new Error("A " + this.kind + " cannot contain nodes of type " + docNode.kind);
        }
        this._nodes.push(docNode);
    };
    /**
     * Append nodes to the collection.
     */
    DocNodeContainer.prototype.appendNodes = function (docNodes) {
        for (var _i = 0, docNodes_1 = docNodes; _i < docNodes_1.length; _i++) {
            var docNode = docNodes_1[_i];
            this.appendNode(docNode);
        }
    };
    /**
     * Remove all nodes from the collection.
     */
    DocNodeContainer.prototype.clearNodes = function () {
        this._nodes.length = 0;
    };
    return DocNodeContainer;
}(DocNode_1.DocNode));
exports.DocNodeContainer = DocNodeContainer;
//# sourceMappingURL=DocNodeContainer.js.map