import { Excerpt } from '../parser/Excerpt';
import { DocNode, IDocNodeParameters } from './DocNode';
/**
 * Constructor parameters for {@link DocNodeLeaf}.
 */
export interface IDocNodeLeafParameters extends IDocNodeParameters {
    excerpt?: Excerpt;
}
/**
 * Abstract base class for `DocNode` subclasses that correspond to input text,
 * i.e. can have an associated Excerpt object.
 */
export declare abstract class DocNodeLeaf extends DocNode {
    private _excerpt;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocNodeLeafParameters);
    /**
     * If this DocNode was created by parsing an input, the `DocNode.excerpt`
     * property can be used to track the associated input text.  This can be useful
     * for highlighting matches during refactoring or highlighting error locations.
     */
    readonly excerpt: Excerpt | undefined;
    /** @override */
    updateParameters(parameters: IDocNodeLeafParameters): void;
    /**
     * Allows the DocNodeLeaf.excerpt to be updated after the object was constructed.
     */
    updateExcerpt(excerpt: Excerpt | undefined): void;
}
